/*----------------------------------------------------------------------------
 * Name:    Blinky.c
 * Purpose: LED Flasher for SAM4L-XPRO
 *----------------------------------------------------------------------------
 * This file is part of the uVision/ARM development tools.
 * This software may only be used under the terms of a valid, current,
 * end user licence from KEIL for a compatible version of KEIL software
 * development tools. Nothing else gives you the right to use this software.
 *
 * This software is supplied "AS IS" without warranties of any kind.
 *
 * Copyright (c) 2004-2014 Keil - An ARM Company. All rights reserved.
 *----------------------------------------------------------------------------*/

#include "sam4l.h"                      // Device header
#include "cmsis_os.h"                   // ARM::CMSIS:RTOS:Keil RTX
#include "Board_Buttons.h"              // ::Board Support:Buttons
#include "Board_LED.h"                  // ::Board Support:LED


/*----------------------------------------------------------------------------
 *      Initialize PLL to 40MHz
 *---------------------------------------------------------------------------*/
void PLL_Initialize(void)
{
  /* set Flash Waite State to maximum */
  HFLASHC->FLASHCALW_FCR = FLASHCALW_FCR_FWS;

  /* set system clock to 40MHz (80 MHz RC Oscillator / 2) */
  SCIF->SCIF_UNLOCK  = SCIF_UNLOCK_KEY(0xAAu) |
                       SCIF_UNLOCK_ADDR((uint32_t)&SCIF->SCIF_RC80MCR - (uint32_t)SCIF);
  SCIF->SCIF_RC80MCR = SCIF_RC80MCR_EN;
  while((SCIF->SCIF_RC80MCR & SCIF_RC80MCR_EN) != SCIF_RC80MCR_EN);

  PM->PM_UNLOCK = PM_UNLOCK_KEY(0xAAu) |   /* Disable write protect           */
                  PM_UNLOCK_ADDR((uint32_t)&PM->PM_CPUSEL - (uint32_t)PM);
  PM->PM_CPUSEL = PM_CPUSEL_CPUDIV;             /* 80 MHz / 2                 */
  while((PM->PM_SR & PM_SR_CKRDY) != PM_SR_CKRDY);

  PM->PM_UNLOCK = PM_UNLOCK_KEY(0xAAu) |        /* Disable write protect      */
                  PM_UNLOCK_ADDR((uint32_t)&PM->PM_MCCTRL - (uint32_t)PM);
  PM->PM_MCCTRL = PM_MCCTRL_MCSEL(4);
  while((PM->PM_SR & PM_SR_CKRDY) != PM_SR_CKRDY);
}

/*----------------------------------------------------------------------------
  Main function
 *----------------------------------------------------------------------------*/
int main (void) {
  int32_t max_num = LED_GetCount() - 1;
  int32_t num = 0;

  SystemCoreClockUpdate();
  PLL_Initialize();

  LED_Initialize();                         /* LED Initialization             */
  Buttons_Initialize();                     /* Buttons Initialization         */

  while (1) {
    LED_On(num);                            /* Turn specified LED on          */
    osDelay(500);                           /* Wait 500ms                     */
    while (Buttons_GetState() & (1 << 0));  /* Wait while holding USER button */
    LED_Off(num);                           /* Turn specified LED off         */
    osDelay(500);                           /* Wait 500ms                     */
    while (Buttons_GetState() & (1 << 0));  /* Wait while holding USER button */
  }
}
